@@ -2,8 +2,9 @@
 
 __author__ = 'Chris Mitchell'
 
-import argparse
+from pythomics.templates import CustomParser
 import sys
+import argparse
 import operator
 import pythomics.parsers.fasta as fasta
 import pythomics.genomics.parsers as gp
@@ -14,23 +15,16 @@ fasta file. It can also incorporate variants given in a VCF file
 while generating this fasta file.
 """
 
-parser = argparse.ArgumentParser(description = description)
-parser.add_argument('-f', '--fasta', nargs='?', help="The fasta file to reference.", type=argparse.FileType('r'), default=sys.stdin)
-parser.add_argument('-o', '--out', nargs='?', help="The file to write resulting fasta file to.", type=argparse.FileType('w'), default=sys.stdout)
+parser = CustomParser(description = description)
+parser.add_fasta(help="The fasta file to reference.")
+parser.add_out(help="The file to write resulting fasta file to.")
 gff_group = parser.add_argument_group('GFF file related options')
 gff_group.add_argument('--gff', help="The GFF file to use.", type=argparse.FileType('r'), required=True)
 gff_group.add_argument('--group-on', help="The key to group entries together by (such as transcript_id)", type=str, default='ID')
 gff_group.add_argument('--feature', help="The feature to use for fetching coordinates (such as CDS, does not apply with cufflinks flag).", type=str, default='')
 gff_group.add_argument('--cufflinks', help="If the gff file is in the standard cufflinks output", action='store_true', default=False)
 vcf_group = parser.add_argument_group('VCF file related options')
-vcf_group.add_argument('--vcf', help="The VCF file to use.", type=argparse.FileType('r'))
-vcf_group.add_argument('--no-homozygous', help="Don't include homozygous variants (default to include)", action='store_false', default=False)
-vcf_group.add_argument('--heterozygous', help="Use heterozygous variants", action='store_true', default=False)
-vcf_group.add_argument('--no-snps', help="Use SNPs (default to False).", action='store_false', default=False)
-vcf_group.add_argument('--dels', help="Use Deletions.", action='store_true', default=False)
-vcf_group.add_argument('--ins', help="Use Insertions.", action='store_true', default=False)
-vcf_group.add_argument('--individual', help="The Individual to use.", type=int, default=1)
-vcf_group.add_argument('--append-chromosome', help="Should 'chr' be appended to the chromosome column?.", action='store_true', default=False)
+vcf_group.add_vcf()
 vcf_group.add_argument('--variants-only', help="Only output transcripts with variants.", action='store_true', default=False)
 splice_group = parser.add_argument_group('Splice Junction Options (if a variant falls over a exon-exon junction. Default is to ignore.)')
 splice_group.add_argument('--splice-partial', help="Partially splice variants (only include exonic portions of variant)", action='store_true', default=False)
